Usage
cnv.call(data, sample.id, segs.stat, maxL = NULL, N = 1000, pvalue.cutoff = 0.05, seed = NULL, do.manual.baseline=FALSE, log2mBAF.left=NULL, log2mBAF.right=NULL, log2ratio.bottom=NULL, log2ratio.up=NULL)
Arguments
data
a data frame containing log2ratio and log2mBAF data generated
by cnv.data.
sample.id
sample ID to be displayed.
maxL
integer. The maximum length in terms of number of probes a bootstrapped segment
may span. Default is NULL. If NULL, It will be automatically specified
as 1/100 of the number of data points.
N
the number of replicates drawn by bootstrap.
pvalue.cutoff
a p-value cut-off for CNV calling.
seed
integer. Random seed can be set for reproducibility of results.
do.manual.baseline
logical. If baseline adjustment to be done manually. Default is FALSE.
log2mBAF.left, log2mBAF.right, log2ratio.bottom, log2ratio.up
left, right, bottom and up boundaries to be specified manually by a visual inspectio of
2-D diagnosis plot generated by diagnosis.cluster.plot.
These parameters are active when do.manual.baseline=TRUE.