Learn R Programming

saasCNV (version 0.3.4)

diagnosis.seg.plot.chr: Visualize Segmentation Results for Diagnosis

Description

The results from joint segmentation and segments merging are visualized for the specified choromosome.

Usage

diagnosis.seg.plot.chr(data, segs, sample.id = "Sample", chr = 1, cex = 0.3)

Arguments

data
a data frame containing log2ratio and log2mBAF data generated by cnv.data.
segs
a data frame containing segment locations and summary statistics resulting from joint.segmentation or merging.segments.
sample.id
sample ID to be displayed in the title of the plot.
chr
the chromosome number (e.g. 1) to be visualized.
cex
a numerical value giving the amount by which plotting text and symbols should be magnified relative to the default. It can be adjusted in order to make the plot legible.

Value

An R plot will be generated.

See Also

joint.segmentation, merging.segments, cnv.data

Examples

Run this code
## visual diagnosis of joint segmentation results
data(seq.data)
data(seq.segs)
diagnosis.seg.plot.chr(data=seq.data, segs=seq.segs, 
                       sample.id="Joint Segmentation", 
                       chr=1, cex=0.3)

## visual diagnosis of results from merging step
data(seq.segs.merge)
diagnosis.seg.plot.chr(data=seq.data, segs=seq.segs.merge, 
                       sample.id="After Segments Merging Step", 
                       chr=1, cex=0.3)

Run the code above in your browser using DataLab