Learn R Programming

saasCNV (version 0.3.4)

saasCNV-package: Somatic Copy Number Alteration Analysis Using Sequencing and SNP Array Data

Description

Perform joint segmentation on two signal dimensions derived from total read depth (intensity) and allele specific read depth (intensity) for whole genome sequencing (WGS), whole exome sequencing (WES) and SNP array data.

Arguments

Details

Package:
saasCNV
Type:
Package
Version:
0.3.4
Date:
2016-05-10
License:
GPL (>= 2)
See the vignettes of the package for more details.

References

Zhang, Z. and Hao, K. (2015) SAAS-CNV: A joint segmentation approach on aggregated and allele specific signals for the identification of somatic copy number alterations with next-generation sequencing Data. PLoS Computational Biology, 11(11):e1004618.

Zhang, N. R., Siegmund, D. O., Ji, H., Li, J. Z. (2010) Detecting simultaneous changepoints in multiple sequences. Biometrika, 97(3):631--645.

See Also

DNAcopy

Examples

Run this code
## See the vignettes of the package for examples.

Run the code above in your browser using DataLab