Learn R Programming

saasCNV (version 0.3.4)

snp.cnv.data: Construct Data Frame for CNV Inference with SNP Array Data

Description

Transform LRR and BAF information into log2ratio and log2mBAF that we use for joint segmentation and CNV calling.

Usage

snp.cnv.data(snp, min.chr.probe = 100, verbose = FALSE)

Arguments

snp
a data frame with LRR and BAF information from SNP array. See the example below for details.
min.chr.probe
the minimum number of probes tagging a chromosome for it to be passed to the subsequent analysis.
verbose
logical. If more details to be output. Default is FALSE.

Value

A data frame containing the log2raio and log2mBAF values for each probe site.

References

Staaf, J., Vallon-Christersson, J., Lindgren, D., Juliusson, G., Rosenquist, R., Hoglund, M., Borg, A., Ringner, M. (2008) Normalization of Illumina Infinium whole-genome SNP data improves copy number estimates and allelic intensity ratios. BMC bioinformatics, 9:409.

See Also

cnv.data

Examples

Run this code
## Not run: 
# ## an example data with LRR and BAF information
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/snp_table.txt.gz"
# tryCatch({download.file(url=url, destfile="snp_table.txt.gz")
#          }, error = function(e) {
#           download.file(url=url, destfile="snp_table.txt.gz", method="curl")
#          })
# ## If download.file fails to download the data, please manually download it from the url.
# 
# snp_table <- read.delim(file="snp_table.txt.gz", as.is=TRUE)
# snp.data <- snp.cnv.data(snp=snp_table, min.chr.probe=100, verbose=TRUE) 
# 
# ## see how seq.data looks like
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/snp.data.RData"
# tryCatch({download.file(url=url, destfile="snp.data.RData")
#          }, error = function(e) {
#           download.file(url=url, destfile="snp.data.RData", method="curl")
#          })
# ## If download.file fails to download the data, please manually download it from the url.
# 
# load("snp.data.RData")
# head(snp.data)
# ## End(Not run)

Run the code above in your browser using DataLab