## Not run:
# ## NGS pipeline analysis
# ## download vcf_table.txt.gz
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/vcf_table.txt.gz"
# tryCatch({download.file(url=url, destfile="vcf_table.txt.gz")
# }, error = function(e) {
# download.file(url=url, destfile="vcf_table.txt.gz", method="curl")
# })
# ## If download.file fails to download the data, please manually download it from the url.
#
# vcf_table <- read.delim(file="vcf_table.txt.gz", as.is=TRUE)
#
# ## download refGene_hg19.txt.gz
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/refGene_hg19.txt.gz"
# tryCatch({download.file(url=url, destfile="refGene_hg19.txt.gz")
# }, error = function(e) {
# download.file(url=url, destfile="refGene_hg19.txt.gz", method="curl")
# })
# ## If download.file fails to download the data, please manually download it from the url.
#
# sample.id <- "WES_0116"
# output.dir <- file.path(getwd(), "test_saasCNV")
#
# NGS.CNV(vcf=vcf_table, output.dir=output.dir, sample.id=sample.id,
# min.chr.probe=100,
# min.snps=10,
# joint.segmentation.pvalue.cutoff=1e-4,
# max.chpts=30,
# do.merge=TRUE, use.null.data=TRUE, num.perm=1000, maxL=2000,
# merge.pvalue.cutoff=0.05,
# do.cnvcall.on.merge=TRUE,
# cnvcall.pvalue.cutoff=0.05,
# do.plot=TRUE, cex=0.3, ref.num.probe=1000,
# do.gene.anno=TRUE,
# gene.anno.file="refGene_hg19.txt.gz",
# seed=123456789,
# verbose=TRUE)
# ## End(Not run)
Run the code above in your browser using DataLab