## Not run:
# ## An example of RefSeq gene annotation file,
# ## the original version of which can be downloaded from UCSC Genome Browser
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/refGene_hg19.txt.gz"
# tryCatch({download.file(url=url, destfile="refGene_hg19.txt.gz")
# }, error = function(e) {
# download.file(url=url, destfile="refGene_hg19.txt.gz", method="curl")
# })
# ## If download.file fails to download the data, please manually download it from the url.
#
# gene.anno <- read.delim(file="refGene_hg19.txt.gz", as.is=TRUE, comment.char="")
# data(seq.cnv)
# seq.cnv.anno <- reannotate.CNV.res(res=seq.cnv, gene=gene.anno, only.CNV=TRUE)
# ## End(Not run)
Run the code above in your browser using DataLab