## Not run:
# ## an example data with LRR and BAF information
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/snp_table.txt.gz"
# tryCatch({download.file(url=url, destfile="snp_table.txt.gz")
# }, error = function(e) {
# download.file(url=url, destfile="snp_table.txt.gz", method="curl")
# })
# ## If download.file fails to download the data, please manually download it from the url.
#
# snp_table <- read.delim(file="snp_table.txt.gz", as.is=TRUE)
# snp.data <- snp.cnv.data(snp=snp_table, min.chr.probe=100, verbose=TRUE)
#
# ## see how seq.data looks like
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/snp.data.RData"
# tryCatch({download.file(url=url, destfile="snp.data.RData")
# }, error = function(e) {
# download.file(url=url, destfile="snp.data.RData", method="curl")
# })
# ## If download.file fails to download the data, please manually download it from the url.
#
# load("snp.data.RData")
# head(snp.data)
# ## End(Not run)
Run the code above in your browser using DataLab