## Not run:
# ## an example VCF file from WES
# ## download WES_example.vcf.gz
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/WES_example.vcf.gz"
# tryCatch({download.file(url=url, destfile="WES_example.vcf.gz")
# }, error = function(e) {
# download.file(url=url, destfile="WES_example.vcf.gz", method="curl")
# })
# ## If download.file fails to download the data, please manually download it from the url.
#
# ## convert VCf file to a data frame
# vcf_table <- vcf2txt(vcf.file="WES_example.vcf.gz", normal.col=9+1, tumor.col=9+2)
#
# ## see how vcf_table looks like
# ## download vcf_table.txt.gz
# url <- "https://zhangz05.u.hpc.mssm.edu/saasCNV/data/vcf_table.txt.gz"
# tryCatch({download.file(url=url, destfile="vcf_table.txt.gz")
# }, error = function(e) {
# download.file(url=url, destfile="vcf_table.txt.gz", method="curl")
# })
# ## If download.file fails to download the data, please manually download it from the url.
#
# vcf_table <- read.delim(file="vcf_table.txt.gz", as.is=TRUE)
# head(vcf_table)
# ## End(Not run)
Run the code above in your browser using DataLab